[PATCH] rockchip: Fix spl mmc boot device ofpath

sunil at amarulasolutions.com sunil at amarulasolutions.com
Fri May 22 20:22:33 CEST 2020


From: Suniel Mahesh <sunil at amarulasolutions.com>

Linux v5.7-rc1 dts(i) sync has changed the sdmmc node from
dwmmc at fe320000 to mmc at fe320000 and this ofpath is being
used in rockchip spl bootdevice code.

So, update the ofpath with a new node name.

Fixes: 167efc2c7a46 ("arm64: dts: rk3399: Sync v5.7-rc1 from Linux"
Signed-off-by: Suniel Mahesh <sunil at amarulasolutions.com>
Signed-off-by: Jagan Teki <jagan at amarulasolutions.com>
---
 arch/arm/mach-rockchip/rk3399/rk3399.c            | 4 ++--
 board/theobroma-systems/puma_rk3399/puma-rk3399.c | 4 ++--
 2 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/arch/arm/mach-rockchip/rk3399/rk3399.c b/arch/arm/mach-rockchip/rk3399/rk3399.c
index 09b0d6e..4fda93b 100644
--- a/arch/arm/mach-rockchip/rk3399/rk3399.c
+++ b/arch/arm/mach-rockchip/rk3399/rk3399.c
@@ -28,7 +28,7 @@ DECLARE_GLOBAL_DATA_PTR;
 const char * const boot_devices[BROM_LAST_BOOTSOURCE + 1] = {
 	[BROM_BOOTSOURCE_EMMC] = "/sdhci at fe330000",
 	[BROM_BOOTSOURCE_SPINOR] = "/spi at ff1d0000",
-	[BROM_BOOTSOURCE_SD] = "/dwmmc at fe320000",
+	[BROM_BOOTSOURCE_SD] = "/mmc at fe320000",
 };
 
 static struct mm_region rk3399_mem_map[] = {
@@ -176,7 +176,7 @@ const char *spl_decode_boot_device(u32 boot_device)
 		u32 boot_device;
 		const char *ofpath;
 	} spl_boot_devices_tbl[] = {
-		{ BOOT_DEVICE_MMC1, "/dwmmc at fe320000" },
+		{ BOOT_DEVICE_MMC1, "/mmc at fe320000" },
 		{ BOOT_DEVICE_MMC2, "/sdhci at fe330000" },
 		{ BOOT_DEVICE_SPI, "/spi at ff1d0000" },
 	};
diff --git a/board/theobroma-systems/puma_rk3399/puma-rk3399.c b/board/theobroma-systems/puma_rk3399/puma-rk3399.c
index 561579d..f7f08ae 100644
--- a/board/theobroma-systems/puma_rk3399/puma-rk3399.c
+++ b/board/theobroma-systems/puma_rk3399/puma-rk3399.c
@@ -77,7 +77,7 @@ static int setup_boottargets(void)
 	}
 
 	/*
 	 * Only run, if booting from mmc1 (i.e. /dwmmc at fe320000) and
 	 * only consider cases where the default boot-order first
 	 * tries to boot from mmc0 (eMMC) and then from mmc1
 	 * (i.e. external SD).
@@ -85,7 +85,7 @@ static int setup_boottargets(void)
 	 * In other words: the SD card will be moved to earlier in the
 	 * order, if U-Boot was also loaded from the SD-card.
 	 */
-	if (!strcmp(boot_device, "/dwmmc at fe320000")) {
+	if (!strcmp(boot_device, "/mmc at fe320000")) {
 		char *mmc0, *mmc1;
 
 		debug("%s: booted from SD-Card\n", __func__);
@@ -77,7 +77,7 @@ static int setup_boottargets(void)
 
 	/*
-	 * Only run, if booting from mmc1 (i.e. /dwmmc at fe320000) and
+	 * Only run, if booting from mmc1 (i.e. /mmc at fe320000) and
 	 * only consider cases where the default boot-order first
 	 * tries to boot from mmc0 (eMMC) and then from mmc1
-- 
2.7.4



More information about the U-Boot mailing list